@@ -368,6 +368,7 @@ IdfViewer <- R6Class("IdfViewer", cloneable = FALSE,
         #'   with a color. All other surfaces will be white.
         #' * `"construction"`: Render the model by surface constructions.
         #' * `"zone"`: Render the model by zones assigned.
+        #' * `"space"`: Render the model by spaces assigned.
         #' * `"normal"`: Render the model by surface normal. The outside
         #'   face of a heat transfer face will be rendered as white and the
         #'   inside face will be rendered as red.
@@ -403,6 +404,10 @@ IdfViewer <- R6Class("IdfViewer", cloneable = FALSE,
         #'        of zones in current [Idf] to show. If `NULL`, no subsetting is
         #'        performed.
         #'
+        #' @param space A character vector of names or an integer vector of IDs
+        #'        of spaces in current [Idf] to show. If `NULL`, no subsetting is
+        #'        performed.
+        #'
         #' @param surface A character vector of names or an integer vector of IDs
         #'        of surfaces in current [Idf] to show. If `NULL`, no subsetting
         #'        is performed.
@@ -420,7 +425,7 @@ IdfViewer <- R6Class("IdfViewer", cloneable = FALSE,
         #' \dontrun{
         #' viewer$show()
         #' }
-        show = function (type = "all", zone = NULL, surface = NULL, width = 1.5, dayl_color = "red", dayl_size = 5)
+        show = function (type = "all", zone = NULL, space = NULL, surface = NULL, width = 1.5, dayl_color = "red", dayl_size = 5)
             idfviewer_show(self, private, type, zone, surface, width = 1.5, dayl_color, dayl_size),
         # }}}
 
@@ -585,7 +590,7 @@ idfviewer_device <- function (self, private) {
 idfviewer_background <- function (self, private, color = "white") {
     assert_string(color)
     private$m_background <- color
-    if (!is.null(self$device())) rgl::rgl.bg(color = color)
+    if (!is.null(self$device())) rgl::bg3d(color = color)
     invisible()
 }
 # }}}
@@ -764,8 +769,8 @@ idfviewer_x_ray <- function (self, private, on = TRUE) {
 }
 # }}}
 # idfviewer_render_by {{{
-idfviewer_render_by <- function (self, private, style = c("surface_type", "boundary", "construction", "zone", "normal")) {
-    assert_choice(style, c("surface_type", "boundary", "construction", "zone", "normal"))
+idfviewer_render_by <- function (self, private, style = c("surface_type", "boundary", "construction", "zone", "space", "normal")) {
+    assert_choice(style, c("surface_type", "boundary", "construction", "zone", "space", "normal"))
 
     private$m_render_by <- style
 
@@ -789,8 +794,8 @@ idfviewer_show <- function (self, private, type = "all", zone = NULL, surface =
 
     # open a new device
     if (!length(self$device())) {
-        rgl::rgl.open()
-        private$m_device <- rgl::rgl.cur()
+        rgl::open3d()
+        private$m_device <- rgl::cur3d()
 
         # apply window size
         rgl::par3d(dev = private$m_device, windowRect = private$m_win_size)
@@ -799,7 +804,7 @@ idfviewer_show <- function (self, private, type = "all", zone = NULL, surface =
         do.call(self$viewpoint, private$m_viewpoint)
 
         # apply background
-        rgl::rgl.bg(color = private$m_background)
+        rgl::bg3d(color = private$m_background)
 
         # apply mouse mode
         do.call(self$mouse_mode, private$m_mouse_mode)
@@ -849,7 +854,7 @@ idfviewer_focus <- function (self, private) {
     if (is.null(self$device())) {
         verbose_info("No viewer window found. Skip.")
     } else {
-        rgl::rgl.set(private$m_device)
+        rgl::set3d(private$m_device)
         rgl::rgl.bringtotop()
     }
 
@@ -861,8 +866,8 @@ idfviewer_close <- function (self, private) {
     if (is.null(self$device())) {
         verbose_info("No viewer window found. Skip.")
     } else {
-        rgl::rgl.set(private$m_device)
-        rgl::rgl.close()
+        rgl::set3d(private$m_device)
+        rgl::close3d()
     }
 
     invisible()
@@ -882,14 +887,16 @@ idfviewer_print <- function (self, private) {
     cli::cat_rule("EnergPlus IDF Geometry Viewer", line = 1)
 
     if (is.null(private$m_geom$parent()$path())) {
-        path <- crayon::bold$bgRed("NOT LOCAL")
+        path <- cli::style_bold(cli::bg_red("NOT LOCAL"))
     } else {
         path <- surround(private$m_geom$parent()$path())
     }
 
-    cli::cat_line(" * ", c(
-        str_trunc(paste0("Path: ", path), width = cli::console_width() - 3L),
-        paste0("Version: ", surround(private$m_geom$parent()$version()))
-    ))
+    cli::cat_line(cli::ansi_strtrim(c(
+        paste0(" ", cli::symbol$bullet, " Path: ", path),
+        paste0(" ", cli::symbol$bullet, " Version: ", surround(private$m_geom$parent()$version()))
+    )))
 }
 # }}}
+
+# vim: set fdm=marker:
