@@ -1,82 +1,89 @@
-use_idd(8.8, "auto")
-
 # NEW {{{
 test_that("$new()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
 
     expect_error(IdfObject$new(1))
     expect_error(IdfObject$new(1, class = "Material", parent = idf))
 
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
     expect_equal(get_priv_env(mat)$m_object_id, 1L)
-    expect_equal(get_priv_env(mat)$m_class_id, 55L)
+    expect_equal(get_priv_env(mat)$m_class_id, 56L)
 
-    expect_is(mat <- IdfObject$new(1, 55, parent = idf), "IdfObject")
+    expect_s3_class(mat <- IdfObject$new(1, 56, parent = idf), "IdfObject")
     expect_equal(get_priv_env(mat)$m_object_id, 1L)
-    expect_equal(get_priv_env(mat)$m_class_id, 55L)
+    expect_equal(get_priv_env(mat)$m_class_id, 56L)
 })
 # }}}
 
 # VERSION {{{
 test_that("$version()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(5, parent = idf), "IdfObject")
-    expect_equal(obj$version(), numeric_version("8.8.0"))
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(5, parent = idf), "IdfObject")
+    expect_equal(obj$version(), numeric_version(LATEST_EPLUS_VER))
 })
 # }}}
 
 # PARENT {{{
 test_that("$parent()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(5, parent = idf), "IdfObject")
-    expect_is(obj$parent(), "Idf")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(5, parent = idf), "IdfObject")
+    expect_s3_class(obj$parent(), "Idf")
 })
 # }}}
 
 # ID {{{
 test_that("$id()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(1, parent = idf), "IdfObject")
     expect_equal(obj$id(), 1L)
 })
 # }}}
 
 # NAME {{{
 test_that("$name()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(1, parent = idf), "IdfObject")
     expect_equal(obj$name(), "WD01")
 })
 # }}}
 
 # GROUP_NAME {{{
 test_that("$group_name()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(2, parent = idf), "IdfObject")
     expect_equal(obj$group_name(), "Surface Construction Elements")
 })
 # }}}
 
 # CLASS_NAME {{{
 test_that("$class_name()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(2, parent = idf), "IdfObject")
     expect_equal(obj$class_name(), "Construction")
 })
 # }}}
 
 # DEFINITION {{{
 test_that("$definition()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(obj <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(obj$definition(), "IddObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(obj <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(obj$definition(), "IddObject")
 })
 # }}}
 
 # COMMENT {{{
 test_that("$comment()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
 
     expect_equal(mat$comment(), " this is a test comment for WD01")
 
@@ -111,11 +118,14 @@ test_that("$comment()", {
 
 # VALUE {{{
 test_that("$value()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8)), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
 
     # can handle cases when both `index` and `name` are NULL
-    expect_equivalent(mat$value(), tolerance = 1e-5,
+    expect_equal(
+        ignore_attr = TRUE, tolerance = 1e-5,
+        mat$value(),
         list(Name = "WD01",
              Roughness = "MediumSmooth",
              Thickness = 0.0191,
@@ -128,7 +138,9 @@ test_that("$value()", {
         )
     )
 
-    expect_equivalent(mat$value(unit = TRUE), tolerance = 1e-5,
+    expect_equal(
+        ignore_attr = TRUE, tolerance = 1e-5,
+        mat$value(unit = TRUE),
         list(Name = "WD01",
              Roughness = "MediumSmooth",
              Thickness = units::set_units(0.0191, "m"),
@@ -150,7 +162,9 @@ test_that("$value()", {
     expect_error(mat$value(c(1, 10:11)), class = "eplusr_error_invalid_field_index")
 
     # can return subset of values in a object using `index`
-    expect_equivalent(mat$value(c(3, 1, 5)), tolerance = 1e-5,
+    expect_equal(
+        ignore_attr = TRUE, tolerance = 1e-5,
+        mat$value(c(3, 1, 5)),
         list(Thickness = 0.0191, Name = "WD01", Density = 513)
     )
     expect_equal(mat[[2]], "MediumSmooth")
@@ -158,8 +172,8 @@ test_that("$value()", {
     expect_equal(mat[c(2,1)], list(Roughness = "MediumSmooth", Name = "WD01"))
 
     # can return subset of values in a object using `name`
-    expect_equivalent(mat$value("Roughness"), list(Roughness = "MediumSmooth"))
-    expect_equivalent(mat$value("Roughness", simplify = TRUE), "MediumSmooth")
+    expect_equal(ignore_attr = TRUE, mat$value("Roughness"), list(Roughness = "MediumSmooth"))
+    expect_equal(ignore_attr = TRUE, mat$value("Roughness", simplify = TRUE), "MediumSmooth")
     expect_equal(mat$Roughness, "MediumSmooth")
 
     # can detect invalid `name` values
@@ -169,14 +183,15 @@ test_that("$value()", {
 
 # SET {{{
 test_that("$set()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(ver <- IdfObject$new(5, parent = idf), "IdfObject")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(surf <- IdfObject$new(3, parent = idf), "IdfObject")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(ver <- IdfObject$new(5, parent = idf), "IdfObject")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(surf <- IdfObject$new(3, parent = idf), "IdfObject")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     # can stop when trying to directly modify `Version` object
-    expect_error(ver$set(8.8), class = "eplusr_error_set_version")
+    expect_error(ver$set(LATEST_EPLUS_VER), class = "eplusr_error_set_version")
 
     # can stop when no values are given
     expect_error(con$set(), class = "eplusr_error_validity_check")
@@ -204,7 +219,7 @@ test_that("$set()", {
 
     # can add new values for extensible fields
     expect_silent(surf$set(vertex_5_x_coordinate = 1, vertex_5_y_coordinate = 2, vertex_5_z_coordinate = 3))
-    expect_equal(surf$value()[23:25],
+    expect_equal(surf$value()[24:26],
         list(`Vertex 5 X-coordinate` = 1, `Vertex 5 Y-coordinate` = 2, `Vertex 5 Z-coordinate` = 3)
     )
     # can change referenced values accordingly
@@ -226,12 +241,18 @@ test_that("$set()", {
 
 # VALUE_POSSIBLE {{{
 test_that("$value_possible()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    idd_env <- get_priv_env(idf$definition())$idd_env()
+    cls_id <- idd_env$class[class_name == "Construction", class_id]
+    fld_id <- idd_env$field[class_id == cls_id, field_id]
 
-    expect_equivalent(con$value_possible(),
-        data.table(class_id = 90L, class_name = "Construction", object_id = 2L,
-            object_name = "WALL-1", field_id = 11006:11010, field_index = 1:5,
+    expect_equal(
+        ignore_attr = TRUE,
+        con$value_possible(),
+        data.table(class_id = cls_id, class_name = "Construction", object_id = 2L,
+            object_name = "WALL-1", field_id = fld_id[1:5], field_index = 1:5,
             field_name = c("Name", "Outside Layer", paste("Layer", 2:4)),
             value_id = 10:14, value_chr = c("WALL-1", "WD01", "PW03", "IN02", "GP01"),
             value_num = rep(NA_real_, 5),
@@ -240,9 +261,11 @@ test_that("$value_possible()", {
             source = c(list(NULL), rep(list(c("WD01", "WD02")), 4))
         )
     )
-    expect_equivalent(con$value_possible(6),
-        data.table(class_id = 90L, class_name = "Construction", object_id = 2L,
-            object_name = "WALL-1", field_id = 11011, field_index = 6L,
+    expect_equal(
+        ignore_attr = TRUE,
+        con$value_possible(6),
+        data.table(class_id = cls_id, class_name = "Construction", object_id = 2L,
+            object_name = "WALL-1", field_id = fld_id[6], field_index = 6L,
             field_name = "Layer 5", value_id = -1L, value_chr = NA_character_, value_num = NA_real_,
             auto = NA_character_, default = list(NA_character_),
             choice = list(), range = list(ranger(NA_real_, FALSE, NA_real_, FALSE)),
@@ -254,12 +277,16 @@ test_that("$value_possible()", {
 
 # VALIDATE {{{
 test_that("$validate()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    idd_env <- get_priv_env(idf$definition())$idd_env()
+    cls_id <- idd_env$class[class_name == "Construction", class_id]
+    fld_id <- idd_env$field[class_id == cls_id, field_id]
 
     expect_equal(con$validate()$invalid_reference,
-        data.table(object_id = 2L, object_name = "WALL-1", class_id = 90L,
-            class_name = "Construction", field_id = 11008:11010,
+        data.table(object_id = 2L, object_name = "WALL-1", class_id = cls_id,
+            class_name = "Construction", field_id = fld_id[3:5],
             field_index = 3:5, field_name = paste("Layer", 2:4),
             units = rep(NA_character_, 3L), ip_units = rep(NA_character_, 3L),
             type_enum = 5L, value_id = 12:14,
@@ -270,7 +297,7 @@ test_that("$validate()", {
 
     skip_on_cran()
 
-    idf <- read_idf(file.path(eplus_config(8.8)$dir, "ExampleFiles/5Zone_Transformer.idf"))
+    idf <- read_idf(path_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf"))
     idf$dup(c(my_roof = "ROOF-1", "ROOF-1", "WALL-1"))
     expect_equal(nrow(idf$validate()$invalid_reference), 0L)
 })
@@ -278,11 +305,12 @@ test_that("$validate()", {
 
 # IS_VALID {{{
 test_that("$is_valid()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(ver <- IdfObject$new(5, parent = idf), "IdfObject")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(surf <- IdfObject$new(3, parent = idf), "IdfObject")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(ver <- IdfObject$new(5, parent = idf), "IdfObject")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(surf <- IdfObject$new(3, parent = idf), "IdfObject")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     expect_true(ver$is_valid())
     expect_true(mat$is_valid())
@@ -293,10 +321,18 @@ test_that("$is_valid()", {
 
 # VALUE_RELATION {{{
 test_that("$value_relation()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    idd_env <- get_priv_env(idf$definition())$idd_env()
+    src_cls_id <- idd_env$class[class_name == "Construction", class_id]
+    src_fld_id <- idd_env$field[class_id == src_cls_id, field_id][1]
+    cls_id <- idd_env$class[class_name == "BuildingSurface:Detailed", class_id]
+    fld_id <- idd_env$field[class_id == cls_id, field_id][3]
 
-    expect_equivalent(con$value_relation(1),
+    expect_equal(
+        ignore_attr = TRUE,
+        con$value_relation(1),
         list(
             ref_to = data.table(
                 class_id = integer(), class_name = character(),
@@ -310,13 +346,13 @@ test_that("$value_relation()", {
                 src_enum = integer(), dep = integer()
             ),
             ref_by = data.table(
-                class_id = 103L, class_name = "BuildingSurface:Detailed",
+                class_id = cls_id, class_name = "BuildingSurface:Detailed",
                 object_id = 3L, object_name = "WALL-1PF",
-                field_id = 11624L, field_index = 3L, field_name = "Construction Name",
+                field_id = fld_id, field_index = 3L, field_name = "Construction Name",
                 value_id = 17L, value_chr = "WALL-1", value_num = NA_integer_, type_enum = 5L,
-                src_class_id = 90L, src_class_name = "Construction",
+                src_class_id = src_cls_id, src_class_name = "Construction",
                 src_object_id = 2L, src_object_name = "WALL-1",
-                src_field_id = 11006L, src_field_index = 1L, src_field_name = "Name",
+                src_field_id = src_fld_id, src_field_index = 1L, src_field_name = "Name",
                 src_value_id = 10L, src_value_chr = "WALL-1", src_value_num = NA_integer_, src_type_enum = 4L,
                 src_enum = 2L, dep = 0L
             ),
@@ -333,12 +369,14 @@ test_that("$value_relation()", {
             )
         )
     )
-    expect_equivalent(con$value_relation(1, keep = TRUE),
+    expect_equal(
+        ignore_attr = TRUE,
+        con$value_relation(1, keep = TRUE),
         list(
             ref_to = data.table(
-                class_id = 90L, class_name = "Construction",
+                class_id = src_cls_id, class_name = "Construction",
                 object_id = 2L, object_name = "WALL-1",
-                field_id = 11006L, field_index = 1L, field_name = "Name",
+                field_id = src_fld_id, field_index = 1L, field_name = "Name",
                 value_id = 10L, value_chr = "WALL-1", value_num = NA_real_, type_enum = 4L,
                 src_class_id = NA_integer_, src_class_name = NA_character_,
                 src_object_id = NA_integer_, src_object_name = NA_character_,
@@ -347,13 +385,13 @@ test_that("$value_relation()", {
                 src_enum = NA_integer_, dep = 0L
             ),
             ref_by = data.table(
-                class_id = 103L, class_name = "BuildingSurface:Detailed",
+                class_id = cls_id, class_name = "BuildingSurface:Detailed",
                 object_id = 3L, object_name = "WALL-1PF",
-                field_id = 11624L, field_index = 3L, field_name = "Construction Name",
+                field_id = fld_id, field_index = 3L, field_name = "Construction Name",
                 value_id = 17L, value_chr = "WALL-1", value_num = NA_integer_, type_enum = 5L,
-                src_class_id = 90L, src_class_name = "Construction",
+                src_class_id = src_cls_id, src_class_name = "Construction",
                 src_object_id = 2L, src_object_name = "WALL-1",
-                src_field_id = 11006L, src_field_index = 1L, src_field_name = "Name",
+                src_field_id = src_fld_id, src_field_index = 1L, src_field_name = "Name",
                 src_value_id = 10L, src_value_chr = "WALL-1", src_value_num = NA_integer_, src_type_enum = 4L,
                 src_enum = 2L, dep = 0L
             ),
@@ -362,9 +400,9 @@ test_that("$value_relation()", {
                 object_id = NA_integer_, object_name = NA_character_,
                 field_id = NA_integer_, field_index = NA_integer_, field_name = NA_character_,
                 value_id = NA_integer_, value_chr = NA_character_, value_num = NA_real_, type_enum = NA_integer_,
-                src_class_id = 90L, src_class_name = "Construction",
+                src_class_id = src_cls_id, src_class_name = "Construction",
                 src_object_id = 2L, src_object_name = "WALL-1",
-                src_field_id = 11006L, src_field_index = 1L, src_field_name = "Name",
+                src_field_id = src_fld_id, src_field_index = 1L, src_field_name = "Name",
                 src_value_id = 10L, src_value_chr = "WALL-1", src_value_num = NA_real_, src_type_enum = 4L,
                 src_enum = NA_integer_, dep = 0L
             )
@@ -375,9 +413,10 @@ test_that("$value_relation()", {
 
 # REF {{{
 test_that("$ref_to_object()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
-    expect_is(ver <- IdfObject$new(5, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    expect_s3_class(ver <- IdfObject$new(5, parent = idf), "IdfObject")
 
     expect_message(with_verbose(ver$ref_to_object()), "does not refer")
     expect_message(with_verbose(ver$ref_to_object(class = "Material")), "does not refer")
@@ -392,8 +431,8 @@ test_that("$ref_to_object()", {
 
     skip_on_cran()
 
-    idf <- read_idf(file.path(eplus_config(8.8)$dir, "ExampleFiles/5Zone_Transformer.idf"))
-    expect_is(loop <- IdfObject$new(278, parent = idf), "IdfObject")
+    idf <- read_idf(path_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf"))
+    expect_s3_class(loop <- IdfObject$new(278, parent = idf), "IdfObject")
     expect_equal(length(loop$ref_to_node()), 9)
 
     expect_equal(con$has_ref(), c(TRUE, TRUE, FALSE, FALSE, FALSE))
@@ -410,9 +449,10 @@ test_that("$ref_to_object()", {
 
 # TO_TABLE {{{
 test_that("$to_table()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     expect_equal(
         con$to_table(all = FALSE, unit = TRUE, wide = FALSE, string_value = TRUE),
@@ -435,7 +475,8 @@ test_that("$to_table()", {
             value = as.list(c("WALL-1", "WD01", "PW03", "IN02", "GP01", rep(NA_character_, 6)))
         )
     )
-    expect_equivalent(
+    expect_equal(
+        ignore_attr = TRUE,
         con$to_table(all = TRUE, unit = TRUE, wide = TRUE, string_value = FALSE),
         data.table(id = 2L, name = "WALL-1", class = "Construction",
             Name = "WALL-1", `Outside Layer` = "WD01", `Layer 2` = "PW03",
@@ -444,7 +485,8 @@ test_that("$to_table()", {
             `Layer 9` = NA_character_, `Layer 10` = NA_character_
         )
     )
-    expect_equivalent(tolerance = 1e-5,
+    expect_equal(
+        ignore_attr = TRUE, tolerance = 1e-5,
         mat$to_table(string_value = FALSE),
         data.table(id = 1L, name = "WD01", class = "Material", index = 1:9,
             field = mat$definition()$field_name(),
@@ -454,7 +496,8 @@ test_that("$to_table()", {
             )
         )
     )
-    expect_equivalent(tolerance = 1e-5,
+    expect_equal(
+        ignore_attr = TRUE, tolerance = 1e-5,
         mat$to_table(wide = TRUE, string_value = FALSE),
         data.table(id = 1L, name = "WD01", class = "Material", Name = "WD01",
             `Roughness` = "MediumSmooth",
@@ -471,8 +514,9 @@ test_that("$to_table()", {
 
 # TO_STRING {{{
 test_that("$to_string()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     expect_equal(con$to_string(leading = 0, sep_at = 10),
         c("Construction,",
@@ -502,9 +546,10 @@ test_that("$to_string()", {
 
 # PRINT {{{
 test_that("$print()", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(ver <- IdfObject$new(5, parent = idf), "IdfObject")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(ver <- IdfObject$new(5, parent = idf), "IdfObject")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     expect_output(ver$print())
     expect_output(ver$print(brief = TRUE))
@@ -512,9 +557,9 @@ test_that("$print()", {
     expect_output(con$print(all = TRUE), "11 :")
     expect_output(con$print(auto_sep = FALSE))
 
-    expect_is(idf <- read_idf(example(), 8.8), "Idf")
-    expect_is(ver <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(out <- IdfObject$new(40, parent = idf), "IdfObject")
+    expect_s3_class(idf <- read_idf(path_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf"), LATEST_EPLUS_VER), "Idf")
+    expect_s3_class(ver <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(out <- IdfObject$new(40, parent = idf), "IdfObject")
     expect_output(ver$print())
     expect_output(out$print())
 })
@@ -522,10 +567,11 @@ test_that("$print()", {
 
 # S3 FORMAT {{{
 test_that("format.IdfObject, as.character.IdfObject, etc", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
-    expect_is(format(con), "character")
+    expect_type(format(con), "character")
     expect_equal(as.character(con), con$to_string())
     expect_output(str(con))
     expect_output(print(con))
@@ -534,8 +580,9 @@ test_that("format.IdfObject, as.character.IdfObject, etc", {
 
 # S3 SUBSET {{{
 test_that("$.IdfObject and [[.IdfObject", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
 
     expect_error(mat[1, 2])
     expect_equal(mat[1:2], list(Name = "WD01", Roughness = "MediumSmooth"))
@@ -547,14 +594,15 @@ test_that("$.IdfObject and [[.IdfObject", {
     expect_null(mat[["roughness"]])
     expect_error(mat[[1:2]])
 
-    expect_is(mat[["version"]], "function")
+    expect_type(mat[["version"]], "closure")
 })
 # }}}
 
 # S3 ASSIGN {{{
 test_that("$<-.IdfObject and [[<-.IdfObject", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
 
     expect_error(mat$name <- "Smooth")
     expect_silent(mat$Roughness <- "Smooth")
@@ -580,9 +628,10 @@ test_that("$<-.IdfObject and [[<-.IdfObject", {
 
 # S3 EQUITY {{{
 test_that("==.IdfObject and !=.IdfObject", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
-    expect_is(mat <- IdfObject$new(1, parent = idf), "IdfObject")
-    expect_is(con <- IdfObject$new(2, parent = idf), "IdfObject")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
+    expect_s3_class(mat <- IdfObject$new(1, parent = idf), "IdfObject")
+    expect_s3_class(con <- IdfObject$new(2, parent = idf), "IdfObject")
 
     expect_false(con == TRUE)
     expect_true(con == con)
@@ -594,23 +643,27 @@ test_that("==.IdfObject and !=.IdfObject", {
 
 # IDF_OBJECT {{{
 test_that("idf_object()", {
+    skip_on_cran()
     expect_error(idf_object())
 
-    idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto"))
+    idf <- read_idf(idftext("idf"))
 
     expect_error(idf_object(parent = idf))
 
     expect_error(idf_object(idf, class = "Construction"))
-    expect_is(obj <- without_checking(idf_object(idf, class = "Construction")), "IdfObject")
+    expect_s3_class(obj <- without_checking(idf_object(idf, class = "Construction")), "IdfObject")
     expect_equal(obj$class_name(), "Construction")
 
-    expect_is(idf_object(idf, 5), "IdfObject")
+    expect_s3_class(idf_object(idf, 5), "IdfObject")
 })
 # }}}
 
 # AUTOCOMPLETE {{{
 test_that(".DollarNames.Idf", {
-    expect_is(idf <- read_idf(idftext("idf", 8.8), use_idd(8.8, "auto")), "Idf")
+    skip_on_cran()
+    expect_s3_class(idf <- read_idf(idftext("idf")), "Idf")
     expect_equal(.DollarNames.Idf(idf, "Ma"), "Material")
 })
 # }}}
+
+# vim: set fdm=marker:
