@@ -2,35 +2,35 @@ test_that("Parametric methods", {
     skip_on_cran()
 
     # can stop if idf is not saved
-    expect_error(param_job(empty_idf(8.8), NULL), class = "eplusr_error_idf_not_local")
+    expect_error(param_job(empty_idf(LATEST_EPLUS_VER), NULL), class = "eplusr_error_idf_not_local")
 
-    path_idf <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
-    path_epw <- path_eplus_weather(8.8, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_idf <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     param <- param_job(path_idf, path_epw)
 
     # $version()
-    expect_equal(param$version(), numeric_version("8.8.0"))
+    expect_equal(param$version(), numeric_version(LATEST_EPLUS_VER))
 
     # $seed()
-    expect_is(param$seed(), "Idf")
+    expect_s3_class(param$seed(), "Idf")
 
     # $weather()
-    expect_is(param$weather(), "Epw")
+    expect_s3_class(param$weather(), "Epw")
     expect_null(param_job(path_idf, NULL)$weather())
 })
 
 test_that("$apply_measure()", {
     skip_on_cran()
 
-    path_idf <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path_idf <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path_idf, NULL)
 
     mea <- function(idf, num) idf
 
     expect_error(param$apply_measure(function(idf) idf))
     expect_error(param$apply_measure(function(idf, ...) 1, a = 1:5))
-    expect_is(param$apply_measure(mea, num = 1:2, .names = "case"), "ParametricJob")
+    expect_s3_class(param$apply_measure(mea, num = 1:2, .names = "case"), "ParametricJob")
     expect_equal(names(param$models()), c("case_1", "case_2"))
     expect_error(param$apply_measure(mea, num = 1:2, .names = c("a", "b", "c")))
 
@@ -44,15 +44,15 @@ test_that("$apply_measure()", {
 test_that("$param()", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path, NULL)
 
-    expect_is(class = "ParametricJob",
+    expect_s3_class(class = "ParametricJob",
         param$param("Supply Fan 1" = list(fan_total_efficiency = c(0.1, 0.5, 0.8)), .cross = TRUE)
     )
     expect_equal(length(param$models()), 3L)
 
-    expect_is(class = "ParametricJob",
+    expect_s3_class(class = "ParametricJob",
         param$param(
             Material := list(Thickness = seq(0.1, 1, length.out = 3), Conductivity = seq(0.1, 0.6, length.out = 3)),
             "Supply Fan 1" = list(fan_total_efficiency = c(0.1, 0.5, 0.8))
@@ -60,7 +60,7 @@ test_that("$param()", {
     )
     expect_equal(length(param$models()), 3L)
 
-    expect_is(class = "ParametricJob",
+    expect_s3_class(class = "ParametricJob",
         param$param(
             Material := list(Thickness = seq(0.1, 1, length.out = 3), Conductivity = seq(0.1, 0.6, length.out = 3)),
             "Supply Fan 1" = list(fan_total_efficiency = c(0.1, 0.5, 0.8)),
@@ -75,7 +75,7 @@ test_that("$param()", {
             .names = c("p1", "p2")
         )
     )
-    expect_is(class = "ParametricJob",
+    expect_s3_class(class = "ParametricJob",
         param$param(
             "Supply Fan 1" = list(fan_total_efficiency = c(0.1, 0.5, 0.8)),
             .names = "fan_eff"
@@ -87,7 +87,7 @@ test_that("$models()", {
     skip_on_cran()
 
     eplusr_option(verbose_info = FALSE)
-    path_idf <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path_idf <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path_idf, NULL)
 
     expect_null(param$models())
@@ -95,7 +95,7 @@ test_that("$models()", {
 
     param$apply_measure(function(idf, num) idf, num = 1:2)
 
-    expect_is(param$models(), "list")
+    expect_type(param$models(), "list")
     expect_equal(length(param$models()), 2)
     expect_equal(names(param$models()), c("case_1", "case_2"))
 
@@ -106,7 +106,7 @@ test_that("$models()", {
 test_that("$cases()", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
 
     param <- param_job(path, NULL)
 
@@ -119,7 +119,9 @@ test_that("$cases()", {
         ),
         c("GP01", "GP02") := .(thickness = c(0.01, 0.02))
     )
-    expect_equivalent(param$cases(),
+    expect_equal(
+        ignore_attr = TRUE,
+        param$cases(),
         data.table(
             index = 1:2, case = c("case_1", "case_2"),
             param_1 = c(0.1, 0.2),
@@ -136,7 +138,9 @@ test_that("$cases()", {
         c("FanAvailSched", "Always On"),
         eff = c(0.1, 0.2)
     )
-    expect_equivalent(param$cases(),
+    expect_equal(
+        ignore_attr = TRUE,
+        param$cases(),
         data.table(index = 1:2, case = c("case_1", "case_2"),
             eff = c(0.1, 0.2), sch = c("FanAvailSched", "Always On")
         )
@@ -146,7 +150,7 @@ test_that("$cases()", {
 test_that("$run()", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path, NULL)
 
     expect_error(param$run(), "No measure")
@@ -155,30 +159,34 @@ test_that("$run()", {
     param$models()[[1L]]$set(Material := list(thickness = 0.05))
     expect_warning(param$run())
 
-    path_epw <- path_eplus_weather(8.8, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
     param <- param_job(path, path_epw)
     param$apply_measure(function(idf, num) idf, num = 1:2)
-    expect_is(param$run(), "ParametricJob")
+    expect_s3_class(param$run(), "ParametricJob")
 })
 
 test_that("$save()", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path, NULL)
     expect_error(param$save())
 
     param$apply_measure(function(idf, num) idf, num = 1:2)
-    expect_equivalent(param$save(),
+    expect_equal(
+        ignore_attr = TRUE,
+        param$save(),
         data.table(
             model = normalizePath(file.path(tempdir(), c("case_1", "case_2"), c("case_1.idf", "case_2.idf"))),
             weather = NA_character_
         )
     )
 
-    param <- param_job(path, path_eplus_weather(8.8, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw"))
+    param <- param_job(path, path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw"))
     param$apply_measure(function(idf, num) idf, num = 1:2)
-    expect_equivalent(param$save(separate = FALSE),
+    expect_equal(
+        ignore_attr = TRUE,
+        param$save(separate = FALSE),
         data.table(
             model = normalizePath(file.path(tempdir(), c("case_1.idf", "case_2.idf"))),
             weather = normalizePath(file.path(tempdir(), "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw"))
@@ -189,7 +197,7 @@ test_that("$save()", {
 test_that("$print()", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path, NULL)
     expect_output(param$print())
 
@@ -201,10 +209,12 @@ test_that("$print()", {
 test_that("==.ParametricJob and !=.ParametricJob", {
     skip_on_cran()
 
-    path <- copy_eplus_example(8.8, "5Zone_Transformer.idf")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "5Zone_Transformer.idf")
     param <- param_job(path, NULL)
 
     expect_false(param == 1)
     expect_true(param == param)
     expect_false(param != param)
 })
+
+# vim: set fdm=marker:
