@@ -21,25 +21,25 @@ test_that("clean_wd()", {
 test_that("path_eplus()", {
     skip_on_cran()
 
-    expect_equal(basename(path_eplus(8.8, "a", "b")), "b")
-    expect_error(basename(path_eplus(8.8, "a", "b", strict = TRUE)))
+    expect_equal(basename(path_eplus(LATEST_EPLUS_VER, "a", "b")), "b")
+    expect_error(basename(path_eplus(LATEST_EPLUS_VER, "a", "b", strict = TRUE)))
 
-    expect_true(is.character(path_eplus_processor(8.8, "EPMacro", strict = TRUE)))
-    expect_true(is.character(path_eplus_processor(8.8, "PreProcess", "GrndTempCalc", "Slab", strict = TRUE)))
+    expect_true(is.character(path_eplus_processor(LATEST_EPLUS_VER, "EPMacro", strict = TRUE)))
+    expect_true(is.character(path_eplus_processor(LATEST_EPLUS_VER, "PreProcess", "GrndTempCalc", "Slab", strict = TRUE)))
 
-    expect_true(is.character(path_eplus_example(8.8, "1ZoneUncontrolled.idf")))
-    expect_true(is.character(path_eplus_example(8.8, "BasicFiles/Exercise1A.idf")))
+    expect_true(is.character(path_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")))
+    expect_true(is.character(path_eplus_example(LATEST_EPLUS_VER, "BasicFiles/Exercise1A.idf")))
 
-    expect_true(is.character(path_eplus_weather(8.8, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.ddy")))
+    expect_true(is.character(path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.ddy")))
 
-    expect_true(is.character(path_eplus_dataset(8.8, "Boilers.idf")))
-    expect_true(is.character(path_eplus_dataset(8.8, "FMUs/MoistAir.fmu")))
+    expect_true(is.character(path_eplus_dataset(LATEST_EPLUS_VER, "Boilers.idf")))
+    expect_true(is.character(path_eplus_dataset(LATEST_EPLUS_VER, "FMUs/MoistAir.fmu")))
 })
 
 test_that("copy_energyplus_idd()", {
     skip_on_cran()
 
-    expect_silent(res <- copy_energyplus_idd(path_eplus(8.8, "energyplus"), tempdir()))
+    expect_silent(res <- copy_energyplus_idd(path_eplus(LATEST_EPLUS_VER, "energyplus"), tempdir()))
     expect_true(file.exists(file.path(tempdir(), "Energy+.idd")))
     expect_true(attr(res, "copied"))
 
@@ -49,7 +49,7 @@ test_that("copy_energyplus_idd()", {
 
     unlink(file.path(tempdir(), "Energy+.idd"))
 
-    expect_silent(res <- copy_energyplus_idd(NULL, tempdir(), path_eplus(8.8, "Energy+.idd")))
+    expect_silent(res <- copy_energyplus_idd(NULL, tempdir(), path_eplus(LATEST_EPLUS_VER, "Energy+.idd")))
     expect_true(file.exists(file.path(tempdir(), "Energy+.idd")))
     unlink(file.path(tempdir(), "Energy+.idd"))
 })
@@ -62,15 +62,15 @@ test_that("EPMacro()", {
 
     main <- file.path(out_dir, "macro.imf")
     part <- file.path(out_dir, "part.idf")
-    write_lines("##include part.idf\nVersion,8.8;", main)
+    write_lines(sprintf("##include part.idf\nVersion,%s;", LATEST_EPLUS_VER), main)
     write_lines("Building,\nBldg;", part)
 
-    res <- EPMacro(part, echo = FALSE, eplus = 8.8)
+    res <- EPMacro(part, echo = FALSE, eplus = LATEST_EPLUS_VER)
     expect_equal(names(res), c("file", "run"))
     expect_equal(res$file, NULL)
     expect_equal(res$run, NULL)
 
-    res <- EPMacro(main, echo = FALSE, eplus = 8.8)
+    res <- EPMacro(main, echo = FALSE, eplus = LATEST_EPLUS_VER)
     expect_equal(names(res), c("file", "run"))
     expect_true(file.exists(res$file$imf))
     expect_true(file.exists(res$file$epmidf))
@@ -122,19 +122,19 @@ test_that("ExpandObjects()", {
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
     path <- file.path(out_dir, "expandobj.idf")
-    write_lines(
-        "Version, 8.8;
+    write_lines(sprintf(
+        "Version, %s;
         HVACTemplate:Thermostat,
             All Zones,
             ,
             20,
             ,
             26;
-        ",
+        ", LATEST_EPLUS_VER),
         path
     )
 
-    res <- ExpandObjects(path, echo = FALSE, idd = path_eplus(8.8, "Energy+.idd"))
+    res <- ExpandObjects(path, echo = FALSE, idd = path_eplus(LATEST_EPLUS_VER, "Energy+.idd"))
     expect_equal(names(res), c("file", "run"))
     expect_equal(names(res$file), c("idf", "expidf", "basement", "slab", "experr"))
     expect_true(file.exists(res$file$idf))
@@ -198,7 +198,7 @@ test_that("Basement()", {
            1;
 
          MatlProps,
-           6,
+           1,
            2242.6,
            2242.6,
            311.66,
@@ -267,16 +267,16 @@ test_that("Basement()", {
            TRUE;
 
          EquivAutoGrid,
-           15,
+           1,
            0.1,
-           2.4;
+           0.5;
         ",
         path
     )
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- Basement(path, weather, echo = FALSE, eplus = 8.8,
-        idd = path_eplus(8.8, "PreProcess", "GrndTempCalc", "BasementGHT.idd")
+    res <- Basement(path, weather, echo = FALSE, eplus = LATEST_EPLUS_VER,
+        idd = path_eplus(LATEST_EPLUS_VER, "PreProcess", "GrndTempCalc", "BasementGHT.idd")
     )
     expect_equal(names(res), c("file", "run"))
     expect_equal(names(res$file), c("idf", "epw", "bsmt_idf", "bsmt_csv", "bsmt_out", "bsmt_audit"))
@@ -306,7 +306,7 @@ test_that("Slab()", {
     path <- file.path(out_dir, "slab.idf")
     write_lines(
         "Materials,
-             2,
+             1,
              0.158,
              0.379,
              0.9,
@@ -365,10 +365,10 @@ test_that("Slab()", {
         ",
         path
     )
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- Slab(path, weather, eplus = 8.8, echo = FALSE,
-        idd = path_eplus(8.8, "PreProcess", "GrndTempCalc", "SlabGHT.idd")
+    res <- Slab(path, weather, eplus = LATEST_EPLUS_VER, echo = FALSE,
+        idd = path_eplus(LATEST_EPLUS_VER, "PreProcess", "GrndTempCalc", "SlabGHT.idd")
     )
     expect_equal(names(res), c("file", "run"))
     expect_equal(names(res$file), c("idf", "epw", "slab_gtp", "slab_out", "slab_ger"))
@@ -393,23 +393,25 @@ test_that("EnergyPlus()", {
     out_dir <- file.path(tempdir(), "Energyplus")
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
-    path <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- EnergyPlus(path, weather, out_dir, eplus = 8.8, echo = FALSE)
+    res <- EnergyPlus(path, weather, out_dir, eplus = LATEST_EPLUS_VER, echo = FALSE)
     expect_equal(names(res), c("file", "run"))
     expect_equal(length(res$file), 51L)
     expect_equal(
         sort(names(which(vapply(res$file, function(x) !anyNA(x), logical(1))))),
         c("audit", "bnd", "dxf", "eio", "end", "epw", "err", "eso", "idf",
-            "mdd", "mtd", "mtr", "rdd", "shd", "sqlite_err", "table")
+            # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+            # a SQLite output
+            "mdd", "mtd", "mtr", "rdd", "shd", "table")
     )
     expect_equal(names(res$run), c("process", "exit_status", "stdout",
         "stderr", "start_time", "end_time"))
     expect_false(is.null(res$run$stdout))
 
     # can use legacy output name style
-    res_legacy <- EnergyPlus(path, weather, out_dir, output_suffix = "L", eplus = 8.8, echo = FALSE)
+    res_legacy <- EnergyPlus(path, weather, out_dir, output_suffix = "L", eplus = LATEST_EPLUS_VER, echo = FALSE)
     files <- basename(unlist(res_legacy$file, FALSE, FALSE))
     files <- files[!is.na(files)]
     expect_equal(setdiff(
@@ -417,12 +419,14 @@ test_that("EnergyPlus()", {
         c("1ZoneUncontrolled", "eplusout", "eplustbl", "sqlite",
           "USA_CO_Golden-NREL.724666_TMY3")
     ), character())
-    expect_equal(sort(as.integer(tbl)), c(1L, 1L, 1L, 5L, 12L))
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal(sort(as.integer(tbl)), c(1L, 1L, 5L, 12L))
 
     # can run annual simulation with custom IDD
     expect_silent(
-        EnergyPlus(path, weather, out_dir, annual = TRUE, eplus = 8.8,
-            echo = FALSE, idd = path_eplus(8.8, "Energy+.idd")
+        EnergyPlus(path, weather, out_dir, annual = TRUE, eplus = LATEST_EPLUS_VER,
+            echo = FALSE, idd = path_eplus(LATEST_EPLUS_VER, "Energy+.idd")
         )
     )
 
@@ -436,13 +440,13 @@ test_that("convertESOMTR()", {
     out_dir <- file.path(tempdir(), "convertESOMTR")
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
-    path <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- EnergyPlus(path, weather, out_dir, eplus = 8.8, echo = FALSE)
+    res <- EnergyPlus(path, weather, out_dir, eplus = LATEST_EPLUS_VER, echo = FALSE)
 
-    eso <- convertESOMTR(res$file$eso, eplus = 8.8, echo = FALSE,
-        rules = path_eplus(8.8, "PostProcess", "convertESOMTRpgm", "convert.txt")
+    eso <- convertESOMTR(res$file$eso, eplus = LATEST_EPLUS_VER, echo = FALSE,
+        rules = path_eplus(LATEST_EPLUS_VER, "PostProcess", "convertESOMTRpgm", "convert.txt")
     )
     expect_equal(names(eso), c("file", "run"))
     expect_equal(names(eso$file), c("eso", "mtr", "ipeso", "ipmtr", "iperr"))
@@ -457,7 +461,7 @@ test_that("convertESOMTR()", {
     expect_true(is.null(eso$run$stderr))
     unlink(unlist(eso$file))
 
-    mtr <- convertESOMTR(res$file$mtr, eplus = 8.8, echo = FALSE)
+    mtr <- convertESOMTR(res$file$mtr, eplus = LATEST_EPLUS_VER, echo = FALSE)
     expect_equal(names(mtr), c("file", "run"))
     expect_equal(names(mtr$file), c("eso", "mtr", "ipeso", "ipmtr", "iperr"))
     expect_true(file.exists(mtr$file$mtr))
@@ -482,12 +486,12 @@ test_that("ReadVarsESO()", {
     out_dir <- file.path(tempdir(), "ReadVarsESO")
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
-    path <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    path <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- EnergyPlus(path, weather, out_dir, eplus = 8.8, echo = FALSE)
+    res <- EnergyPlus(path, weather, out_dir, eplus = LATEST_EPLUS_VER, echo = FALSE)
 
-    eso <- ReadVarsESO(res$file$eso, eplus = 8.8, echo = FALSE)
+    eso <- ReadVarsESO(res$file$eso, eplus = LATEST_EPLUS_VER, echo = FALSE)
     expect_equal(names(eso), c("file", "run"))
     expect_equal(names(eso$file), c("eso", "mtr", "variable", "meter", "rvaudit"))
     expect_true(file.exists(eso$file$eso))
@@ -502,7 +506,7 @@ test_that("ReadVarsESO()", {
     expect_true(!is.na(eso$file$rvaudit))
     unlink(unlist(eso$file))
 
-    mtr <- ReadVarsESO(res$file$mtr, eplus = 8.8, echo = FALSE)
+    mtr <- ReadVarsESO(res$file$mtr, eplus = LATEST_EPLUS_VER, echo = FALSE)
     expect_equal(names(mtr$file), c("eso", "mtr", "variable", "meter", "rvaudit"))
     expect_true(file.exists(mtr$file$mtr))
     expect_true(file.exists(mtr$file$meter))
@@ -527,10 +531,10 @@ test_that("HVAC_Diagram()", {
     out_dir <- file.path(tempdir(), "HVAC_Diagram")
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
-    model <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    model <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
-    res <- EnergyPlus(model, weather, out_dir, eplus = 8.8, echo = FALSE)
+    res <- EnergyPlus(model, weather, out_dir, eplus = LATEST_EPLUS_VER, echo = FALSE)
 
     svg <- HVAC_Diagram(res$file$bnd, echo = FALSE)
     expect_equal(names(svg), c("file", "run"))
@@ -553,30 +557,32 @@ test_that("energyplus()", {
     out_dir <- file.path(tempdir(), "run-energyplus")
     if (!dir.exists(out_dir)) dir.create(out_dir)
 
-    weather <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    weather <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
     # can run EPMacro
-    path_imf <- copy_eplus_example(8.8, "AbsorptionChiller_Macro.imf")
+    path_imf <- copy_eplus_example(LATEST_EPLUS_VER, "AbsorptionChiller_Macro.imf")
     path_resources <- c(
-        copy_eplus_example(8.8, "HVAC3ZoneChillerSpec.imf"),
-        copy_eplus_example(8.8, "HVAC3ZoneGeometry.imf"),
-        copy_eplus_example(8.8, "HVAC3Zone-IntGains-Def.imf"),
-        copy_eplus_example(8.8, "HVAC3ZoneMat-Const.imf")
+        copy_eplus_example(LATEST_EPLUS_VER, "HVAC3ZoneChillerSpec.imf"),
+        copy_eplus_example(LATEST_EPLUS_VER, "HVAC3ZoneGeometry.imf"),
+        copy_eplus_example(LATEST_EPLUS_VER, "HVAC3Zone-IntGains-Def.imf"),
+        copy_eplus_example(LATEST_EPLUS_VER, "HVAC3ZoneMat-Const.imf")
     )
     res_imf <- energyplus(path_imf, weather, out_dir, echo = FALSE, resources = path_resources)
     expect_equal(names(res_imf), c("version", "energyplus", "start_time", "end_time", "exit_status", "output_dir", "file", "run"))
-    expect_equal(as.character(res_imf$version), "8.8.0")
-    expect_equal(res_imf$energyplus, eplus_config(8.8)$dir)
-    expect_is(res_imf$start_time, "POSIXct")
-    expect_is(res_imf$end_time, "POSIXct")
+    expect_equal(as.character(res_imf$version), LATEST_EPLUS_VER)
+    expect_equal(res_imf$energyplus, eplus_config(LATEST_EPLUS_VER)$dir)
+    expect_s3_class(res_imf$start_time, "POSIXct")
+    expect_s3_class(res_imf$end_time, "POSIXct")
     expect_equal(res_imf$output_dir, normalizePath(out_dir))
     expect_equal(length(res_imf$file), 57L)
-    expect_equal({files <- unlist(res_imf$file); files <- files[!is.na(files)]; length(files)}, 24L)
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal({files <- unlist(res_imf$file); files <- files[!is.na(files)]; length(files)}, 23L)
     expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
     expect_equal(sort(unname(files[names(files) != "epw"])),
         sort(c(list.files(out_dir, "AbsorptionChiller_Macro"), basename(path_resources)))
     )
-    expect_is(res_imf$run, "data.table")
+    expect_s3_class(res_imf$run, "data.table")
     expect_equal(names(res_imf$run),
         c("program", "exit_status", "start_time", "end_time", "stdout", "stderr")
     )
@@ -594,10 +600,12 @@ test_that("energyplus()", {
     unlink(c(path_imf, path_resources, out_dir), recursive = TRUE)
 
     # can run ExpandObjects
-    path_exp <- copy_eplus_example(8.8, "HVACTemplate-5ZoneFanCoil.idf")
+    path_exp <- copy_eplus_example(LATEST_EPLUS_VER, "HVACTemplate-5ZoneFanCoil.idf")
     res_exp <- energyplus(path_exp, weather, out_dir, echo = FALSE)
     expect_equal(length(res_exp$file), 57L)
-    expect_equal({files <- unlist(res_exp$file); files <- files[!is.na(files)]; length(files)}, 23L)
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal({files <- unlist(res_exp$file); files <- files[!is.na(files)]; length(files)}, 22L)
     expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
     expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "HVACTemplate-5ZoneFanCoil"))
     expect_equal(res_exp$run[program == "ExpandObjects", exit_status], list(0L))
@@ -606,28 +614,37 @@ test_that("energyplus()", {
     unlink(c(path_exp, out_dir), recursive = TRUE)
 
     if(Sys.getenv("_EPLUSR_SKIP_TESTS_BASEMENT_") == "") {
-        # can run Basement
-        path_base <- copy_eplus_example(8.8, "LgOffVAVusingBasement.idf")
-        expect_error(energyplus(path_base, NULL, out_dir, echo = FALSE))
-        # modify the input in order to reduce the simulation time
-        l <- read_lines(path_base)
-        l[grepl("IYRS: Maximum number of yearly iterations", string), string := "1;"]
-        write_lines(l, path_base)
-        res_base <- energyplus(path_base, weather, out_dir, design_day = TRUE, echo = FALSE)
-        expect_equal(length(res_base$file), 57L)
-        expect_equal({files <- unlist(res_base$file); files <- files[!is.na(files)]; length(files)}, 27L)
-        expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
-        expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "LgOffVAVusingBasement"))
-        expect_equal(res_base$run[program == "Basement", exit_status], list(0L))
-        expect_true(file.exists(file.path(out_dir, files["expidf"])))
-        expect_true(file.exists(file.path(out_dir, files["bsmt_idf"])))
-        expect_true(file.exists(file.path(out_dir, files["bsmt_csv"])))
-        expect_true(file.exists(file.path(out_dir, files["bsmt_out"])))
-        expect_true(file.exists(file.path(out_dir, files["bsmt_audit"])))
-        unlink(c(path_base, out_dir), recursive = TRUE)
+        # NOTE: There is a bug in the basement preprocessor in EnergyPlus from v9.4 to v22.1
+        # Ref: https://github.com/NREL/EnergyPlus/pull/9356
+        if (numeric_version(LATEST_EPLUS_VER) > 22.1) {
+            # can run Basement
+            path_base <- copy_eplus_example(LATEST_EPLUS_VER, "LgOffVAVusingBasement.idf")
+            expect_error(energyplus(path_base, NULL, out_dir, echo = FALSE))
+            # modify the input in order to reduce the simulation time
+            l <- read_lines(path_base)
+            l[grepl("IYRS: Maximum number of yearly iterations", string), string := "1;"]
+            l[grepl("NMAT: Number of materials in this domain", string), string := "1,"]
+            l[grepl("CLEARANCE: Distance from outside of wall", string), string := "1,"]
+            l[grepl("BaseDepth: Depth of the basement wall", string), string := "0.5;"]
+            write_lines(l, path_base)
+            res_base <- energyplus(path_base, weather, out_dir, design_day = TRUE, echo = FALSE)
+            expect_equal(length(res_base$file), 57L)
+            # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+            # a SQLite output
+            expect_equal({files <- unlist(res_base$file); files <- files[!is.na(files)]; length(files)}, 26L)
+            expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
+            expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "LgOffVAVusingBasement"))
+            expect_equal(res_base$run[program == "Basement", exit_status], list(0L))
+            expect_true(file.exists(file.path(out_dir, files["expidf"])))
+            expect_true(file.exists(file.path(out_dir, files["bsmt_idf"])))
+            expect_true(file.exists(file.path(out_dir, files["bsmt_csv"])))
+            expect_true(file.exists(file.path(out_dir, files["bsmt_out"])))
+            expect_true(file.exists(file.path(out_dir, files["bsmt_audit"])))
+            unlink(c(path_base, out_dir), recursive = TRUE)
+        }
 
         # can run Slab
-        path_slab <- copy_eplus_example(8.8, "5ZoneAirCooledWithSlab.idf")
+        path_slab <- copy_eplus_example(LATEST_EPLUS_VER, "5ZoneAirCooledWithSlab.idf")
         expect_error(energyplus(path_slab, NULL, out_dir, echo = FALSE))
         # modify the input in order to reduce the simulation time
         l <- read_lines(path_slab)
@@ -636,7 +653,9 @@ test_that("energyplus()", {
         write_lines(l, path_slab)
         res_slab <- energyplus(path_slab, weather, out_dir, echo = FALSE)
         expect_equal(length(res_slab$file), 57L)
-        expect_equal({files <- unlist(res_slab$file); files <- files[!is.na(files)]; length(files)}, 26L)
+        # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+        # a SQLite output
+        expect_equal({files <- unlist(res_slab$file); files <- files[!is.na(files)]; length(files)}, 25L)
         expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
         expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "5ZoneAirCooledWithSlab"))
         expect_equal(res_slab$run[program == "Slab", exit_status], list(0L))
@@ -647,10 +666,12 @@ test_that("energyplus()", {
     }
 
     # can convert eso to IP
-    path_ip <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
+    path_ip <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
     res_ip <- energyplus(path_ip, weather, out_dir, eso_to_ip = TRUE, echo = FALSE)
     expect_equal(length(res_ip$file), 57L)
-    expect_equal({files <- unlist(res_ip$file); files <- files[!is.na(files)]; length(files)}, 26L)
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal({files <- unlist(res_ip$file); files <- files[!is.na(files)]; length(files)}, 25L)
     expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
     expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "1ZoneUncontrolled"))
     expect_equal(res_ip$run[program == "convertESOMTR", exit_status], list(0L))
@@ -660,7 +681,9 @@ test_that("energyplus()", {
     unlink(out_dir, recursive = TRUE)
     res_ip2 <- energyplus(path_ip, weather, out_dir, eso_to_ip = TRUE, readvars = FALSE, echo = FALSE)
     expect_equal(length(res_ip2$file), 57L)
-    expect_equal({files2 <- unlist(res_ip2$file); files2 <- files2[!is.na(files2)]; length(files2)}, 23L)
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal({files2 <- unlist(res_ip2$file); files2 <- files2[!is.na(files2)]; length(files2)}, 22L)
     expect_equal(sum(!file.exists(file.path(out_dir, files2))), 0L)
     expect_true(file.exists(file.path(out_dir, files2["ipeso"])))
     expect_true(file.exists(file.path(out_dir, files2["ipmtr"])))
@@ -669,11 +692,13 @@ test_that("energyplus()", {
 
     # can run with EnergyPlus < 8.3
     options("eplusr.eplus_legacy" = TRUE)
-    path_legacy <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
+    path_legacy <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
     expect_error(energyplus(path_legacy, weather, out_dir, design_day = TRUE, echo = FALSE))
     res_legacy <- energyplus(path_legacy, weather, out_dir, echo = FALSE)
     expect_equal(length(res_legacy$file), 57L)
-    expect_equal({files <- unlist(res_legacy$file); files <- files[!is.na(files)]; length(files)}, 24L)
+    # NOTE: From EnergyPlus v22.1.0, Sqlite.err is only generated if there is
+    # a SQLite output
+    expect_equal({files <- unlist(res_legacy$file); files <- files[!is.na(files)]; length(files)}, 23L)
     expect_equal(sum(!file.exists(file.path(out_dir, files))), 0L)
     expect_equal(sort(unname(files[names(files) != "epw"])), list.files(out_dir, "1ZoneUncontrolled"))
     unlink(out_dir, recursive = TRUE)
@@ -688,13 +713,13 @@ test_that("energyplus()", {
 test_that("run_idf()", {
     skip_on_cran()
 
-    path_idf <- copy_eplus_example(8.8, "1ZoneUncontrolled.idf")
-    path_epw <- path_eplus_weather(8.8, "USA_CO_Golden-NREL.724666_TMY3.epw")
+    path_idf <- copy_eplus_example(LATEST_EPLUS_VER, "1ZoneUncontrolled.idf")
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CO_Golden-NREL.724666_TMY3.epw")
 
     # can run ddy simulation
-    expect_is(res <- run_idf(path_idf, NULL, output_dir = tempdir(), echo = FALSE), "list")
+    expect_type(res <- run_idf(path_idf, NULL, output_dir = tempdir(), echo = FALSE), "list")
     # can specify EnergyPlus version
-    expect_is(res <- run_idf(path_idf, NULL, output_dir = tempdir(), echo = FALSE, eplus = 8.8), "list")
+    expect_type(res <- run_idf(path_idf, NULL, output_dir = tempdir(), echo = FALSE, LATEST_EPLUS_VER), "list")
     expect_null(res$epw)
     # can stop if failed to find version
     expect_error({
@@ -703,53 +728,53 @@ test_that("run_idf()", {
         run_idf(f, NULL, output_dir = tempdir(), echo = FALSE)
     }, "Missing version field")
     # can use input file directory
-    expect_is({
+    expect_type({
         f <- tempfile(fileext = ".idf")
         file.copy(path_idf, f, overwrite = TRUE)
         res <- run_idf(f, NULL, output_dir = NULL, echo = FALSE)
     }, "list")
 
     # can run simulation with weather
-    expect_is(res <- run_idf(path_idf, path_epw, output_dir = tempdir(), echo = FALSE), "list")
+    expect_type(res <- run_idf(path_idf, path_epw, output_dir = tempdir(), echo = FALSE), "list")
     expect_equal(res$idf, normalizePath(path_idf))
     expect_equal(res$epw, normalizePath(path_epw))
-    expect_equal(res$version, numeric_version("8.8.0"))
+    expect_equal(res$version, numeric_version(LATEST_EPLUS_VER))
     expect_equal(res$exit_status, 0L)
-    expect_is(res$start_time, "POSIXct")
-    expect_is(res$end_time, "POSIXct")
+    expect_s3_class(res$start_time, "POSIXct")
+    expect_s3_class(res$end_time, "POSIXct")
     expect_equal(res$output_dir, normalizePath(tempdir(), mustWork = FALSE))
-    expect_equal(res$energyplus, normalizePath(file.path(eplus_config(8.8)$dir, eplus_config(8.8)$exe), mustWork = TRUE))
-    expect_is(res$stdout, "character")
+    expect_equal(res$energyplus, eplus_exe(LATEST_EPLUS_VER))
+    expect_type(res$stdout, "character")
     expect_true("stderr" %in% names(res))
-    expect_is(res$process, "process")
+    expect_s3_class(res$process, "process")
     expect_true(file.exists(res$idf))
     expect_true(file.exists(res$epw))
 
     # can run in the background
-    expect_is(proc <- run_idf(path_idf, NULL, output_dir = tempdir(), wait = FALSE), "r_process")
-    expect_is({proc$wait(); res <- proc$get_result()}, "list")
+    expect_s3_class(proc <- run_idf(path_idf, NULL, output_dir = tempdir(), wait = FALSE), "r_process")
+    expect_type({proc$wait(); res <- proc$get_result()}, "list")
     expect_equal(res$idf, normalizePath(path_idf))
     expect_null(res$epw)
-    expect_equal(res$version, numeric_version("8.8.0"))
+    expect_equal(res$version, numeric_version(LATEST_EPLUS_VER))
     expect_equal(res$exit_status, 0L)
-    expect_is(res$start_time, "POSIXct")
-    expect_is(res$end_time, "POSIXct")
+    expect_s3_class(res$start_time, "POSIXct")
+    expect_s3_class(res$end_time, "POSIXct")
     expect_equal(res$output_dir, normalizePath(tempdir(), mustWork = FALSE))
-    expect_equal(res$energyplus, normalizePath(file.path(eplus_config(8.8)$dir, eplus_config(8.8)$exe), mustWork = TRUE))
-    expect_is(res$stdout, "character")
+    expect_equal(res$energyplus, eplus_exe(LATEST_EPLUS_VER))
+    expect_type(res$stdout, "character")
     expect_null(res$process)
 })
 
 test_that("run_multi()", {
     skip_on_cran()
 
-    path_idf <- copy_eplus_example(8.8, c("1ZoneUncontrolled.idf", "5Zone_Transformer.idf"))
-    path_epw <- path_eplus_weather(8.8, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
+    path_idf <- copy_eplus_example(LATEST_EPLUS_VER, c("1ZoneUncontrolled.idf", "5Zone_Transformer.idf"))
+    path_epw <- path_eplus_weather(LATEST_EPLUS_VER, "USA_CA_San.Francisco.Intl.AP.724940_TMY3.epw")
 
     # can stop if idf and epw does not have the same length
     expect_error(run_multi(path_idf, rep(path_epw, 3), NULL), "Must have same length")
     # can stop if idf and eplus does not have the same length
-    expect_error(run_multi(path_idf, NULL, NULL, eplus = rep(8.8, 3)), "Must have same length")
+    expect_error(run_multi(path_idf, NULL, NULL, eplus = rep(LATEST_EPLUS_VER, 3)), "Must have same length")
     # can stop if idf and design does not have the same length
     expect_error(run_multi(path_idf, NULL, NULL, design_day = rep(FALSE, 3)), "Must have same length")
     # can stop if idf and annual does not have the same length
@@ -777,7 +802,7 @@ test_that("run_multi()", {
         res <- run_multi(path_idf, NULL, file.path(tempdir(), c("a", "b"))),
         "FAILED"
     )
-    expect_is(res, "data.table")
+    expect_s3_class(res, "data.table")
     expect_equal(names(res), c("index", "status", "idf", "epw", "version",
             "exit_status", "start_time", "end_time", "output_dir", "energyplus",
             "stdout", "stderr"))
@@ -785,18 +810,18 @@ test_that("run_multi()", {
     expect_equal(res$status, rep("failed", 2))
     expect_equal(res$idf, normalizePath(path_idf))
     expect_equal(res$epw, rep(NA_character_, 2))
-    expect_equal(res$version, rep("8.8.0", 2))
+    expect_equal(res$version, rep(LATEST_EPLUS_VER, 2))
     expect_equal(res$exit_status > 0, rep(TRUE, 2))
-    expect_is(res$start_time, "POSIXct")
-    expect_is(res$end_time, "POSIXct")
-    expect_equal(res$energyplus, rep(normalizePath(file.path(eplus_config(8.8)$dir, eplus_config(8.8)$exe), mustWork = TRUE), 2L))
+    expect_s3_class(res$start_time, "POSIXct")
+    expect_s3_class(res$end_time, "POSIXct")
+    expect_equal(res$energyplus, rep(eplus_exe(LATEST_EPLUS_VER), 2L))
     checkmate::expect_list(res$stdout, "character")
 
     expect_silent(res <- run_multi(path_idf, NULL, file.path(tempdir(), c("a", "b")), wait = FALSE))
-    expect_is(res, "r_process")
+    expect_s3_class(res, "r_process")
     expect_equal({res$wait(); res$get_exit_status()}, 0L)
     expect_silent(res <- res$get_result())
-    expect_is(res, "data.table")
+    expect_s3_class(res, "data.table")
     expect_equal(names(res), c("index", "status", "idf", "epw", "version",
             "exit_status", "start_time", "end_time", "output_dir", "energyplus",
             "stdout", "stderr"))
@@ -804,11 +829,13 @@ test_that("run_multi()", {
     expect_equal(res$status, rep("failed", 2))
     expect_equal(res$idf, normalizePath(path_idf, mustWork = FALSE))
     expect_equal(res$epw, rep(NA_character_, 2))
-    expect_equal(res$version, rep("8.8.0", 2))
+    expect_equal(res$version, rep(LATEST_EPLUS_VER, 2))
     expect_equal(res$exit_status > 0, rep(TRUE, 2))
-    expect_is(res$start_time, "POSIXct")
-    expect_is(res$end_time, "POSIXct")
+    expect_s3_class(res$start_time, "POSIXct")
+    expect_s3_class(res$end_time, "POSIXct")
     expect_equal(res$output_dir, normalizePath(file.path(tempdir(), c("a", "b")), mustWork = FALSE))
-    expect_equal(res$energyplus, rep(normalizePath(file.path(eplus_config(8.8)$dir, eplus_config(8.8)$exe), mustWork = TRUE), 2L))
+    expect_equal(res$energyplus, rep(eplus_exe(LATEST_EPLUS_VER), 2L))
     checkmate::expect_list(res$stdout, "character")
 })
+
+# vim: set fdm=marker:
